//
// merge dialog
//
// Written by Maxwell Sayles.  Copyright (C) 2000.
//

#include <windows.h>
#include <commctrl.h>
#include <stdio.h>
#include "resource.h"
#include "Merge_Dialog.hpp"
#include "util.hpp"



//
// merge dialog box proc
//
BOOL CALLBACK
Merge_Dialog::DialogProc (HWND hWndDlg, UINT uMsg, WPARAM wParam, LPARAM lParam)
{
	switch (uMsg)
	{
		case WM_INITDIALOG:
			{
				// create merge
				Merge_Dialog* dialog = (Merge_Dialog*)(lParam);
				SetWindowLong (hWndDlg, GWL_USERDATA, (LONG)(dialog));
				dialog->hWnd = hWndDlg;
				dialog->initDialog ();
			}
		return TRUE;


		case WM_CLOSE:
			EndDialog (hWndDlg, 0);
		return TRUE;


		case WM_COMMAND:
		{
			Merge_Dialog* dialog = (Merge_Dialog*)(GetWindowLong (hWndDlg, GWL_USERDATA));

			switch (LOWORD (wParam))
			{
				case IDC_PAUSE:
					dialog->pause ();
				return TRUE;

				case IDCANCEL:
					PostMessage (hWndDlg, WM_CLOSE, 0, 0);
				return TRUE;
			}
		}
		return FALSE;
	}

	return FALSE;

}


//
// pause
//
void
Merge_Dialog::pause ()
{
	this->isPaused = !this->isPaused;
	if (this->isPaused)
	{
		SendDlgItemMessage (this->hWnd, IDC_PAUSE, WM_SETTEXT, 0, (LPARAM)("Un&pause"));
	}
	else
	{
		SendDlgItemMessage (this->hWnd, IDC_PAUSE, WM_SETTEXT, 0, (LPARAM)("&Pause"));
	}
}


//
// init dialog
//
void
Merge_Dialog::initDialog ()
{
	// set progress bars from 0 - 100
	HWND hWndDestinationProgress = GetDlgItem (this->hWnd, IDC_DESTINATION_PROGRESS);
	SendMessage (hWndDestinationProgress, PBM_SETRANGE, 0, MAKELPARAM (0, 100));

	HWND hWndSourceProgress = GetDlgItem (this->hWnd, IDC_SOURCE_PROGRESS);
	SendMessage (hWndSourceProgress, PBM_SETRANGE, 0, MAKELPARAM (0, 100));

	// set percent idicators to zero
	HWND hWndDestinationPercent = GetDlgItem (this->hWnd, IDC_DESTINATION_PERCENT);
	SendMessage (hWndDestinationPercent, WM_SETTEXT, 0, (LPARAM)("0.00%"));

	HWND hWndSourcePercent = GetDlgItem (this->hWnd, IDC_SOURCE_PERCENT);
	SendMessage (hWndSourcePercent, WM_SETTEXT, 0, (LPARAM)("0.00%"));
}


//
// set input filename
//
void
Merge_Dialog::setUI_inputFileName (const char* fileName)
{
	char* name = createFileName_from_fullPath (fileName);
	char* temp = new char [strlen (name) + strlen ("Reading: ") + 1];
	strcpy (temp, "Reading: ");
	strcat (temp, name);
	HWND hWndSource = GetDlgItem (this->hWnd, IDC_SOURCE);
	SendMessage (hWndSource, WM_SETTEXT, 0, (LPARAM)(temp));
	delete[] temp;
	delete[] name;
}


//
// set output filename
//
void
Merge_Dialog::setUI_outputFileName (const char* fileName)
{
	char* name = createFileName_from_fullPath (fileName);
	char* temp = new char [strlen (name) + strlen ("Writing: ") + 1];
	strcpy (temp, "Writing: ");
	strcat (temp, name);
	HWND hWndSource = GetDlgItem (this->hWnd, IDC_DESTINATION);
	SendMessage (hWndSource, WM_SETTEXT, 0, (LPARAM)(temp));
	delete[] temp;
	delete[] name;
}



//
// set input percentage
//
void
Merge_Dialog::setUI_inputPercentage (float percentage)
{
	HWND hWndSourceProcess = GetDlgItem (this->hWnd, IDC_SOURCE_PROGRESS);
	SendMessage (hWndSourceProcess, PBM_SETPOS, (WPARAM)(percentage), 0);

	char string [8];
	sprintf (string, "%3.2f%%", percentage);
	HWND hWndSourcePercentage = GetDlgItem (this->hWnd, IDC_SOURCE_PERCENT);
	SendMessage (hWndSourcePercentage, WM_SETTEXT, 0, (LPARAM)(string));
}


//
// set output percentage
//
void
Merge_Dialog::setUI_outputPercentage (float percentage)
{
	HWND hWndDestinationProgress = GetDlgItem (this->hWnd, IDC_DESTINATION_PROGRESS);
	SendMessage (hWndDestinationProgress, PBM_SETPOS, (WPARAM)(percentage), 0);

	char string [8];
	sprintf (string, "%3.2f%%", percentage);
	HWND hWndDestinationPercentage = GetDlgItem (this->hWnd, IDC_DESTINATION_PERCENT);
	SendMessage (hWndDestinationPercentage, WM_SETTEXT, 0, (LPARAM)(string));
}